summaryrefslogtreecommitdiff
path: root/tests
diff options
context:
space:
mode:
Diffstat (limited to 'tests')
-rw-r--r--tests/Makefile.am4
-rw-r--r--tests/tgrandom.c (renamed from tests/turandom_gaussian.c)14
2 files changed, 9 insertions, 9 deletions
diff --git a/tests/Makefile.am b/tests/Makefile.am
index 64f16e7e3..7c234fd96 100644
--- a/tests/Makefile.am
+++ b/tests/Makefile.am
@@ -28,7 +28,7 @@ check_PROGRAMS = tversion tinternals tinits tisqrt tsgn tcheck \
terf texp texp10 texp2 texpm1 tfactorial tfits tfma tfmod \
tfms tfprintf tfrac tfrexp tgamma tget_flt tget_d tget_d_2exp \
tget_f tget_ld_2exp tget_set_d64 tget_sj tget_str tget_z \
- tgmpop thyperbolic thypot tinp_str tj0 tj1 tjn tl2b \
+ tgmpop tgrandom thyperbolic thypot tinp_str tj0 tj1 tjn tl2b \
tlgamma tli2 tlngamma tlog tlog10 tlog1p tlog2 tmin_prec \
tminmax tmodf tmul tmul_2exp tmul_d tmul_ui tnext \
tout_str toutimpl tpow tpow3 tpow_all tpow_z tprintf \
@@ -37,7 +37,7 @@ check_PROGRAMS = tversion tinternals tinits tisqrt tsgn tcheck \
tset_str tset_z tset_z_exp tsi_op tsin tsin_cos tsinh \
tsinh_cosh tsprintf tsqr tsqrt tsqrt_ui tstckintc tstdint tstrtofr \
tsub tsub1sp tsub_d tsub_ui tsubnormal tsum tswap ttan \
- ttanh ttrunc tui_div tui_pow tui_sub turandom turandom_gaussian \
+ ttanh ttrunc tui_div tui_pow tui_sub turandom \
tvalist ty0 ty1 tyn tzeta tzeta_ui tversion
EXTRA_DIST = tgeneric.c tgeneric_ui.c mpf_compat.h inp_str.data tmul.dat
diff --git a/tests/turandom_gaussian.c b/tests/tgrandom.c
index bb4e97bfd..69ae660a8 100644
--- a/tests/turandom_gaussian.c
+++ b/tests/tgrandom.c
@@ -1,6 +1,6 @@
-/* Test file for mpfr_urandom_gaussian
+/* Test file for mpfr_grandom
-Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2006, 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
+Copyright 2011 Free Software Foundation, Inc.
Contributed by the Arenaire and Caramel projects, INRIA.
This file is part of the GNU MPFR Library.
@@ -26,8 +26,8 @@ http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
#include "mpfr-test.h"
static void
-test_urandom_gaussian (long nbtests, mpfr_prec_t prec, mpfr_rnd_t rnd,
- int verbose)
+test_grandom (long nbtests, mpfr_prec_t prec, mpfr_rnd_t rnd,
+ int verbose)
{
mpfr_t *t;
mpfr_t av, va, tmp;
@@ -37,7 +37,7 @@ test_urandom_gaussian (long nbtests, mpfr_prec_t prec, mpfr_rnd_t rnd,
t = malloc (nbtests * sizeof (mpfr_t));
if (t == NULL)
{
- fprintf (stderr, "turandom_gaussian: can't allocate memory in test_urandom_gaussian\n");
+ fprintf (stderr, "tgrandom: can't allocate memory in test_grandom\n");
exit (1);
}
@@ -47,7 +47,7 @@ test_urandom_gaussian (long nbtests, mpfr_prec_t prec, mpfr_rnd_t rnd,
inex = 1;
for (i = 0; i < nbtests; i += 2)
{
- itmp = mpfr_urandom_gaussian (t[i], t[i + 1], RANDS, MPFR_RNDN);
+ itmp = mpfr_grandom (t[i], t[i + 1], RANDS, MPFR_RNDN);
inex = ((itmp & 3) != 0) && ((itmp & 12) != 0) && inex;
}
@@ -107,7 +107,7 @@ main (int argc, char *argv[])
nbtests = a;
}
- test_urandom_gaussian (nbtests, 420, MPFR_RNDN, verbose);
+ test_grandom (nbtests, 420, MPFR_RNDN, verbose);
tests_end_mpfr ();
return 0;